Swedish-Bankernas-kontonummer.csv
Source: https://www-2.danskebank.se/link/Bankernaskontonummer

Also for reference:
https://www.bankgirot.se/globalassets/dokument/anvandarmanualer/bankernaskontonummeruppbyggnad_anvandarmanual_sv.pdf
http://clearingnummer.info/clearingnummer-bokstavsordning/
